summaryrefslogtreecommitdiffstats
path: root/chromium/ui/views/widget/desktop_aura/desktop_factory_ozone.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/ui/views/widget/desktop_aura/desktop_factory_ozone.h')
-rw-r--r--chromium/ui/views/widget/desktop_aura/desktop_factory_ozone.h11
1 files changed, 8 insertions, 3 deletions
diff --git a/chromium/ui/views/widget/desktop_aura/desktop_factory_ozone.h b/chromium/ui/views/widget/desktop_aura/desktop_factory_ozone.h
index e557d3bdb7a..2af191b445f 100644
--- a/chromium/ui/views/widget/desktop_aura/desktop_factory_ozone.h
+++ b/chromium/ui/views/widget/desktop_aura/desktop_factory_ozone.h
@@ -9,11 +9,12 @@
namespace gfx {
class Rect;
+class Screen;
}
namespace views {
class DesktopNativeWidgetAura;
-class DesktopRootWindowHost;
+class DesktopWindowTreeHost;
namespace internal {
class NativeWidgetDelegate;
@@ -30,12 +31,16 @@ class VIEWS_EXPORT DesktopFactoryOzone {
// Sets the implementation delegate. Ownership is retained by the caller.
static void SetInstance(DesktopFactoryOzone* impl);
// Delegates implementation of DesktopRootWindowHost::Create externally to
// Ozone implementation.
- virtual DesktopRootWindowHost* CreateRootWindowHost(
+ virtual DesktopWindowTreeHost* CreateWindowTreeHost(
internal::NativeWidgetDelegate* native_widget_delegate,
DesktopNativeWidgetAura* desktop_native_widget_aura) = 0;
+ // Delegates implementation of DesktopScreen externally to
+ // Ozone implementation.
+ virtual gfx::Screen* CreateDesktopScreen() = 0;
+
private:
static DesktopFactoryOzone* impl_; // not owned
};
@@ -30,12 +31,16 @@ class VIEWS_EXPORT DesktopFactoryOzone {
// Sets the implementation delegate. Ownership is retained by the caller.
static void SetInstance(DesktopFactoryOzone* impl);
- // Delegates implementation of DesktopRootWindowHost::Create externally to
+ // Delegates implementation of DesktopWindowTreeHost::Create externally to
// Ozone implementation.